Module: Devise::Models::KillbillAuthenticatable::ClassMethods
- Defined in:
- lib/devise/models/killbill_authenticatable.rb
Instance Method Summary collapse
-
#find_for_killbill_authentication(kb_username) ⇒ Object
Invoked by the KillbillAuthenticatable strategy to lookup the user before attempting authentication.
Instance Method Details
#find_for_killbill_authentication(kb_username) ⇒ Object
Invoked by the KillbillAuthenticatable strategy to lookup the user before attempting authentication
28 29 30 31 32 33 34 |
# File 'lib/devise/models/killbill_authenticatable.rb', line 28 def find_for_killbill_authentication(kb_username) find_for_authentication(kb_username:) || new(kb_username:) rescue KillBillClient::API::Unauthorized => _e # Multi-Tenancy was enabled, but the tenant_id couldn't be retrieved because of bad credentials nil end |